#!/usr/bin/env python

# quick test to access adc-data from fd
# B. Swinkels and F. Carbognani, Jul 2014

import PyFd as fd
import ctypes
import numpy as np
import matplotlib.pyplot as plt

# create fake argv to feed to FdIOIni
fake_argv = [b'bla', b'fdio_config.cfg', b'my_cm_name']
# http://stackoverflow.com/questions/3494598/
arr = (ctypes.c_char_p * len(fake_argv))()
arr[:] = fake_argv

# start fdio
fdio = fd.FdIONew (len(arr), arr, 'myname')
fd.FdIOParseAndIni(fdio)

# get some frames
for i in range(10):
    frame = fd.FdIOGetFrame(fdio)
    print('gps of current frame:', frame.contents.GTimeS)
    fd.FrameFree(frame)

# get some data
frame = fd.FdIOGetFrame(fdio)
chan = 'V1:SAT_BS_F0_GRD_L1'
data = fd.FrAdcDataFind(frame, chan)
vect = data.contents.data.contents #FrVect
x = np.ctypeslib.as_array(vect.dataI, (vect.nData,))

# plot it
dt = frame.contents.dt
fsamp = len(x) / dt
t = np.arange(0, dt, 1 / fsamp)
plt.plot(t, x)
plt.title(chan)
plt.show()
